# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#                        BURN VECTOR LAYERS                        #
#                                                                  #
####################################################################

This script burns ths vector layers into the raster DEM layers. That
means, that raster cells are overwritten with the values 3000 (rock
outcrops) 20000 (shelf ice) and 30000 (ice sheets and glaciers)
whereever they intersect with the vector layers.

"""


#=============================================================================
#    SCRIPT INFO
#=============================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.1'
__date__ = '2020-12-17'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Developement'


#=============================================================================
#    IMPORT
#=============================================================================

import os

# import AWI Basemap configuration
from config import *


#=============================================================================
#    PROCESS
#=============================================================================

# layer names
add_ice_sheet_name = os.path.splitext(os.path.basename(ADD_ICE_SHEET))[0]
add_shelf_ice_name = os.path.splitext(os.path.basename(ADD_SHELF_ICE))[0]
add_rock_outcrop_name = os.path.splitext(os.path.basename(ADD_ROCK_OUTCROP))[0]
gimp_name = os.path.splitext(os.path.basename(GIMP))[0]
glims_world_name = os.path.splitext(os.path.basename(GLIMS_WORLD))[0]
glims_arctic_name = os.path.splitext(os.path.basename(GLIMS_ARCTIC))[0]
glims_antarctic_name = os.path.splitext(os.path.basename(GLIMS_ANTARCTIC))[0]

# burn values
V_ROCK_OUTCROPS = 3000.0
V_SHELF_ICE = 20000.0
V_ICE_SHEET = 30000.0

# heading
print()
print('============================================================')
print('                     BURN VECTOR LAYERS                     ')

msg = 'Burning Antarctic ice shelfs in World raster...'
cmd = f'gdal_rasterize -l {add_shelf_ice_name} -burn {V_SHELF_ICE} {ADD_SHELF_ICE} {GEBCO_WORLD}'
run(msg,cmd)

msg = 'Burning Antarctic ice sheet in World raster...'
cmd = f'gdal_rasterize -l {add_ice_sheet_name} -burn {V_ICE_SHEET} {ADD_ICE_SHEET} {GEBCO_WORLD}'
run(msg,cmd)

msg = 'Burning Antarctic rock outcrops in World raster...'
cmd = f'gdal_rasterize -l {add_rock_outcrop_name} -burn {V_ROCK_OUTCROPS} -at {ADD_ROCK_OUTCROP} {GEBCO_WORLD}'
run(msg,cmd)

msg = 'Burning Greenland ice sheet in World raster...'
cmd = f'gdal_rasterize -l {gimp_name} -burn {V_ICE_SHEET} {GIMP} {GEBCO_WORLD}'
run(msg,cmd)

msg = 'Burning glaciers in World raster...'
cmd = f'gdal_rasterize -l {glims_world_name} -burn {V_ICE_SHEET} {GLIMS_WORLD} {GEBCO_WORLD}'
run(msg,cmd)

msg = 'Burning Greenland ice sheet in Arctic raster...'
cmd = f'gdal_rasterize -l {gimp_name} -burn {V_ICE_SHEET} {GIMP} {GEBCO_ARCTIC}'
run(msg,cmd)

msg = 'Burning glaciers in Arctic raster...'
cmd = f'gdal_rasterize -l {glims_arctic_name} -burn {V_ICE_SHEET} {GLIMS_ARCTIC} {GEBCO_ARCTIC}'
run(msg,cmd)

msg = 'Burning Antarctic ice shelfs in Antarctic raster...'
cmd = f'gdal_rasterize -l {add_shelf_ice_name} -burn {V_SHELF_ICE} {ADD_SHELF_ICE} {GEBCO_ANTARCTIC}'
run(msg,cmd)

msg = 'Burning Antarctic ice sheet in Antarctic raster...'
cmd = f'gdal_rasterize -l {add_ice_sheet_name} -burn {V_ICE_SHEET} {ADD_ICE_SHEET} {GEBCO_ANTARCTIC}'
run(msg,cmd)

msg = 'Burning Antarctic rock outcrops in Antarctic raster...'
cmd = f'gdal_rasterize -l {add_rock_outcrop_name} -burn {V_ROCK_OUTCROPS} -at {ADD_ROCK_OUTCROP} {GEBCO_ANTARCTIC}'
run(msg,cmd)

msg = 'Burning glaciers in Antarctic raster...'
cmd = f'gdal_rasterize -l {glims_antarctic_name} -burn {V_ICE_SHEET} {GLIMS_ANTARCTIC} {GEBCO_ANTARCTIC}'
run(msg,cmd)

cleanup(ADD_SHELF_ICE)
cleanup(ADD_ICE_SHEET)
cleanup(ADD_ROCK_OUTCROP)
cleanup(GIMP)
cleanup(GLIMS_WORLD)
cleanup(GLIMS_ARCTIC)
cleanup(GLIMS_ANTARCTIC)
